mailr7089 - in /branches/rdc_analysis/prompt: pcs.py rdc.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on August 08, 2008 - 06:12:
Author: bugman
Date: Thu Aug  7 19:30:26 2008
New Revision: 7089

URL: http://svn.gna.org/viewcvs/relax?rev=7089&view=rev
Log:
Renamed the 'RDC identification string' to the 'alignment identification 
string'.


Modified:
    branches/rdc_analysis/prompt/pcs.py
    branches/rdc_analysis/prompt/rdc.py

Modified: branches/rdc_analysis/prompt/pcs.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/rdc_analysis/prompt/pcs.py?rev=7089&r1=7088&r2=7089&view=diff
==============================================================================
--- branches/rdc_analysis/prompt/pcs.py (original)
+++ branches/rdc_analysis/prompt/pcs.py Thu Aug  7 19:30:26 2008
@@ -188,7 +188,7 @@
 
         # Id string.
         if type(id) != str:
-            raise RelaxStrError, ('identification string', id)
+            raise RelaxStrError, ('alignment identification string', id)
 
         # Execute the functional code.
         pcs.display(id=id)
@@ -200,7 +200,7 @@
         Keyword Arguments
         ~~~~~~~~~~~~~~~~~
 
-        id:  The PCS identification string.
+        id:  The alignment identification string.
 
         file:  The name of the file containing the PCS data.
 
@@ -250,7 +250,7 @@
 
         # Id string.
         if type(id) != str:
-            raise RelaxStrError, ('identification string', id)
+            raise RelaxStrError, ('alignment identification string', id)
 
         # The file name.
         if type(file) != str:
@@ -302,7 +302,7 @@
         Keyword Arguments
         ~~~~~~~~~~~~~~~~~
 
-        id:  The PCS identification string.
+        id:  The alignment identification string.
 
         file:  The name of the file.
 
@@ -329,7 +329,7 @@
 
         # Id string.
         if type(id) != str:
-            raise RelaxStrError, ('identification string', id)
+            raise RelaxStrError, ('alignment identification string', id)
 
         # File.
         if type(file) != str:

Modified: branches/rdc_analysis/prompt/rdc.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/rdc_analysis/prompt/rdc.py?rev=7089&r1=7088&r2=7089&view=diff
==============================================================================
--- branches/rdc_analysis/prompt/rdc.py (original)
+++ branches/rdc_analysis/prompt/rdc.py Thu Aug  7 19:30:26 2008
@@ -51,7 +51,7 @@
         Keyword Arguments
         ~~~~~~~~~~~~~~~~~
 
         id:  The RDC identification string.
         """
 
         # Function intro text.
@@ -78,7 +78,7 @@
 
         pipe_to:  The name of the pipe to copy the RDC data to.
 
         id:  The RDC identification string.
 
 
         Description
@@ -126,19 +126,19 @@
 
         # Id string.
         if id != None and type(id) != str:
-            raise RelaxNoneStrError, ('identification string', id)
+            raise RelaxNoneStrError, ('alignment identification string', id)
 
         # Execute the functional code.
         rdc.copy(pipe_from=pipe_from, pipe_to=pipe_to, id=id)
 
 
     def delete(self, id=None):
-        """Delete the RDC data corresponding to id.
-
-        Keyword Arguments
-        ~~~~~~~~~~~~~~~~~
-
-        id:  The RDC identification string.
+        """Delete the RDC data corresponding to the alignment id.
+
+        Keyword Arguments
+        ~~~~~~~~~~~~~~~~~
+
+        id:  The alignment identification string.
 
 
         Examples
@@ -157,19 +157,19 @@
 
         # Id string.
         if type(id) != str:
-            raise RelaxStrError, ('identification string', id)
+            raise RelaxStrError, ('alignment identification string', id)
 
         # Execute the functional code.
         rdc.delete(id=id)
 
 
     def display(self, id=None):
-        """Display the RDC data corresponding to id.
-
-        Keyword Arguments
-        ~~~~~~~~~~~~~~~~~
-
-        id:  The RDC identification string.
+        """Display the RDC data corresponding to the alignment id.
+
+        Keyword Arguments
+        ~~~~~~~~~~~~~~~~~
+
+        id:  The alignment identification string.
 
 
         Examples
@@ -188,7 +188,7 @@
 
         # Id string.
         if type(id) != str:
-            raise RelaxStrError, ('identification string', id)
+            raise RelaxStrError, ('alignment identification string', id)
 
         # Execute the functional code.
         rdc.display(id=id)
@@ -200,7 +200,7 @@
         Keyword Arguments
         ~~~~~~~~~~~~~~~~~
 
         id:  The RDC identification string.
 
         file:  The name of the file containing the RDC data.
 
@@ -250,7 +250,7 @@
 
         # Id string.
         if type(id) != str:
-            raise RelaxStrError, ('identification string', id)
+            raise RelaxStrError, ('alignment identification string', id)
 
         # The file name.
         if type(file) != str:
@@ -302,7 +302,7 @@
         Keyword Arguments
         ~~~~~~~~~~~~~~~~~
 
         id:  The RDC identification string.
 
         file:  The name of the file.
 
@@ -329,7 +329,7 @@
 
         # Id string.
         if type(id) != str:
-            raise RelaxStrError, ('identification string', id)
+            raise RelaxStrError, ('alignment identification string', id)
 
         # File.
         if type(file) != str:
@@ -51,7 +51,7 @@
         ~~~~~~~~~~~~~~~~~
 
-        id:  The RDC identification string.
+        id:  The alignment identification string.
         """
 
@@ -78,7 +78,7 @@
         pipe_to:  The name of the pipe to copy the RDC data to.
 
-        id:  The RDC identification string.
+        id:  The alignment identification string.
 
 
@@ -200,7 +200,7 @@
         ~~~~~~~~~~~~~~~~~
 
-        id:  The RDC identification string.
+        id:  The alignment identification string.
 
         file:  The name of the file containing the RDC data.
@@ -302,7 +302,7 @@
         ~~~~~~~~~~~~~~~~~
 
-        id:  The RDC identification string.
+        id:  The alignment identification string.
 
         file:  The name of the file.




Related Messages


Powered by MHonArc, Updated Fri Aug 08 07:20:10 2008